summary refs log tree commit diff
path: root/nixos/modules
diff options
context:
space:
mode:
authorSilvan Mosberger <infinisil@icloud.com>2019-02-14 21:13:57 +0100
committerGitHub <noreply@github.com>2019-02-14 21:13:57 +0100
commit3df95cfd9a43ee0d4d70de0c3a3dcde14f973566 (patch)
tree2c746e33df9f24e9a0bb2a864d64234546dda86d /nixos/modules
parente69fdc171521a9f0f1cf81ba187ac2a0fd81bc16 (diff)
parentfaac33bc77d4f6c2c010991302954ee6638a10d9 (diff)
downloadnixpkgs-3df95cfd9a43ee0d4d70de0c3a3dcde14f973566.tar
nixpkgs-3df95cfd9a43ee0d4d70de0c3a3dcde14f973566.tar.gz
nixpkgs-3df95cfd9a43ee0d4d70de0c3a3dcde14f973566.tar.bz2
nixpkgs-3df95cfd9a43ee0d4d70de0c3a3dcde14f973566.tar.lz
nixpkgs-3df95cfd9a43ee0d4d70de0c3a3dcde14f973566.tar.xz
nixpkgs-3df95cfd9a43ee0d4d70de0c3a3dcde14f973566.tar.zst
nixpkgs-3df95cfd9a43ee0d4d70de0c3a3dcde14f973566.zip
Merge pull request #55540 from florianjacob/matomo
Security: Matomo 3.7.0 -> 3.8.1
Diffstat (limited to 'nixos/modules')
-rw-r--r--nixos/modules/services/web-apps/matomo.nix17
1 files changed, 11 insertions, 6 deletions
diff --git a/nixos/modules/services/web-apps/matomo.nix b/nixos/modules/services/web-apps/matomo.nix
index e5427c7a564..14aca45a342 100644
--- a/nixos/modules/services/web-apps/matomo.nix
+++ b/nixos/modules/services/web-apps/matomo.nix
@@ -49,12 +49,11 @@ in {
         type = types.nullOr types.str;
         default = null;
         example = "lighttpd";
-        # TODO: piwik.php might get renamed to matomo.php in future releases
         description = ''
           Name of the web server user that forwards requests to the ${phpSocket} fastcgi socket for Matomo if the nginx
           option is not used. Either this option or the nginx option is mandatory.
           If you want to use another webserver than nginx, you need to set this to that server's user
-          and pass fastcgi requests to `index.php` and `piwik.php` to this socket.
+          and pass fastcgi requests to `index.php`, `matomo.php` and `piwik.php` (legacy name) to this socket.
         '';
       };
 
@@ -265,8 +264,11 @@ in {
         locations."= /index.php".extraConfig = ''
           fastcgi_pass unix:${phpSocket};
         '';
-        # TODO: might get renamed to matomo.php in future versions
-        # allow piwik.php for tracking
+        # allow matomo.php for tracking
+        locations."= /matomo.php".extraConfig = ''
+          fastcgi_pass unix:${phpSocket};
+        '';
+        # allow piwik.php for tracking (deprecated name)
         locations."= /piwik.php".extraConfig = ''
           fastcgi_pass unix:${phpSocket};
         '';
@@ -287,8 +289,11 @@ in {
         locations."= /robots.txt".extraConfig = ''
           return 200 "User-agent: *\nDisallow: /\n";
         '';
-        # TODO: might get renamed to matomo.js in future versions
-        # let browsers cache piwik.js
+        # let browsers cache matomo.js
+        locations."= /matomo.js".extraConfig = ''
+          expires 1M;
+        '';
+        # let browsers cache piwik.js (deprecated name)
         locations."= /piwik.js".extraConfig = ''
           expires 1M;
         '';